From: Julian Ospald <hasufell@gentoo.org>
Date: Wed Aug 21 14:26:38 UTC 2013
Subject: several QA fixes

--- a/Makefile
+++ b/Makefile
@@ -1,17 +1,27 @@
-LIBS= `pkg-config --libs glib-2.0 gtk+-2.0 libmenu-cache`
-CFLAGS+= -g -Wall `pkg-config --cflags glib-2.0 gtk+-2.0 libmenu-cache`
-CC=gcc
+CC ?= gcc
+PKG_CONFIG ?= pkg-config
+
+CFLAGS ?= -O2 -g
+CFLAGS += -Wall $(shell $(PKG_CONFIG) --cflags glib-2.0 gtk+-2.0 libmenu-cache)
+LIBS += $(shell $(PKG_CONFIG) --libs glib-2.0 gtk+-2.0 libmenu-cache)
 #-DG_DISABLE_DEPRECATED
 
-# Comment this line if you don't want icons to appear in menu
-CFLAGS+=-DWITH_ICONS
-# Uncomment this line if Openbox can display SVG icons 
-# Check SVG support with '$ ldd /usr/bin/openbox | grep svg', librsvg must appear..
-# CFLAGS+=-DWITH_SVG
-
-prefix= /usr/local
-DESTDIR ?= $(prefix)
-BINDIR= ${DESTDIR}/bin
+# set to 0 to turn off icons in menus
+ICONS=1
+
+# set to 0 to turn off svg icons in menus
+SVG_ICONS=1
+
+ifeq ($(SVG_ICONS),1)
+CPPFLAGS += -DWITH_SVG
+endif
+
+ifeq ($(ICONS),1)
+CPPFLAGS += -DWITH_ICONS
+endif
+
+prefix = /usr
+BINDIR = ${prefix}/bin
 
 SRC= $(shell ls *.c 2> /dev/null)
 OBJ= $(SRC:.c=.o)
@@ -19,26 +29,29 @@
 all: $(OBJ) openbox-menu
 
 %.o: %.c
-	$(CC) $(CFLAGS) -c $< -o $@
+	$(CC) $(CFLAGS) $(CPPFLAGS) -c $< -o $@
 
 openbox-menu: $(OBJ)
-	$(CC) $(OBJ) -o openbox-menu $(LDFLAGS) $(LIBS)
+	$(CC) $(CFLAGS) $(OBJ) -o openbox-menu $(LDFLAGS) $(LIBS)
 
-.PHONY: clean install doc changelog check
+.PHONY: clean install install-strip doc changelog check
 
 clean:
 	@rm -f *.o openbox-menu
 	@rm -rf doc
 
 install:
+	@install -Dm 755 openbox-menu "$(DESTDIR)$(BINDIR)/openbox-menu"
+
+install-strip:
 	@strip -s openbox-menu
-	@install -Dm 755 openbox-menu $(BINDIR)/openbox-menu
+	@install -Dm 755 openbox-menu "$(DESTDIR)$(BINDIR)/openbox-menu"
 
 doc:
 	robodoc --src . --doc doc/ --multidoc --index --html --cmode
 
 check: openbox-menu
-	./openbox-menu > test.xml 
+	./openbox-menu > test.xml
 	xmllint test.xml
 	rm test.xml
 
